@@ -1,6 +1,5 @@
 """NodeProvider classes that add product-specific behaviour."""
 
-import base64
 import copy
 import inspect
 import json
@@ -10,7 +9,6 @@ from types import ModuleType
 from typing import Any, cast, Dict, List, Optional
 
 from openapi_client.rest import ApiException
-from ray import cloudpickle
 from ray.autoscaler._private.aws.node_provider import to_aws_format
 from ray.autoscaler._private.command_runner import DockerCommandRunner, SSHCommandRunner
 from ray.autoscaler._private.util import hash_launch_conf
@@ -257,32 +255,13 @@ class AnyscaleInstanceManagerNodeProvider:
             tags=tags,
             count=count,
         )
-        # Catch, process, and repropagate remote exceptions.
-        remote_exc = None
         try:
             self.api_client.create_nodes_api_v2_instances_post(create_node_request)
         except ApiException as api_exception:
-            try:
-                error_detail = json.loads(api_exception.body)
-                ser_exc = error_detail["error"]["detail"]
-                remote_exc = cloudpickle.loads(base64.b64decode(ser_exc))
-            except Exception as deserialization_error:
-                logger.warn(
-                    "create_node() received an ApiException, "
-                    "but we were unable to deserialize it "
-                    f"({deserialization_error}). "
-                    "Raising the ApiException unchanged."
-                )
-                raise api_exception
-
-        # Raise the unwrapped error away from the try/except clause
-        # so the ApiException codegenned frames do not tag along.
-        if remote_exc:
-            logger.warn(
-                "create_node() received an ApiException. "
-                "Unwrapping and raising the original remote exception instead."
-            )
-            raise remote_exc
+            # Catch, process, and repropagate remote exceptions.
+            error_detail = json.loads(api_exception.body)
+            exception_message = error_detail["error"]["detail"]
+            raise RuntimeError(exception_message)
 
     def set_node_tags(self, node_id: str, tags: Dict[str, str]) -> None:
         if not self.is_provider_supported:
