@@ -163,3 +163,18 @@ ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN = {
         },
     ],
 }
+
+# Used for optional readonly access to SSM
+ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT = {
+    "Version": "2012-10-17",
+    "Statement": {
+        "Sid": "1",
+        "Effect": "Allow",
+        "Action": [
+            "secretsmanager:GetSecretValue",
+            "secretsmanager:DescribeSecret",
+            "secretsmanager:ListSecrets",
+        ],
+        "Resource": "*",
+    },
+}
