@@ -158,7 +158,7 @@ def _configure_min_max_workers(
 
 def configure_for_session(
     session_id: str,
-    project_root_dir: str,
+    project_root_dir: Optional[str] = None,
     api_client: DefaultApi = None,
     disable_project_sync: bool = False,
     _DO_NOT_USE_RAY_UP_ONLY_cluster_config: Optional[  # noqa: N803
@@ -189,6 +189,9 @@ def configure_for_session(
         cluster_config, session_id, api_client
     )
     if not disable_project_sync:
+        assert (
+            project_root_dir
+        ), "Please provide a project_root_dir if syncing project file mounts"
         cluster_config = _update_file_mounts(
             cluster_config, project_root_dir, api_client
         )
@@ -203,7 +206,10 @@ def configure_for_session(
 
 @_with_safe_cluster_config  # type: ignore
 def _set_anyscale_aws_node_provider(
-    cluster_config: Dict[str, Any], session_name: str, api_client: DefaultApi
+    cluster_config: Dict[str, Any],
+    session_name: str,
+    project_id: str,
+    api_client: DefaultApi,
 ) -> Dict[str, Any]:
     """
     Sets the NodeProvider to be one backed by the Anyscale Control Plane. This ensures that
@@ -217,8 +223,6 @@ def _set_anyscale_aws_node_provider(
     if cluster_config["provider"]["type"] != "aws":
         return cluster_config
 
-    project_definition = load_project_or_throw()
-    project_id = get_project_id(project_definition.root)
     session = get_project_session(project_id, session_name, api_client)
 
     cluster_config["provider"]["type"] = "external"
@@ -238,21 +242,25 @@ def get_cluster_config(
     session_name: Optional[str],
     api_client: DefaultApi = None,
     disable_project_sync: bool = False,
+    project_id: Optional[str] = None,
 ) -> Dict[str, Any]:
 
-    project_definition = load_project_or_throw()
-    project_id = get_project_id(project_definition.root)
+    project_definition_root: Optional[str] = None
+    if not project_id or not disable_project_sync:
+        project_definition = load_project_or_throw()
+        project_definition_root = project_definition.root
+        project_id = get_project_id(project_definition.root)
 
     session = get_project_session(project_id, session_name, api_client)
 
     cluster_config = configure_for_session(
         session.id,
-        project_definition.root,
+        project_definition_root,
         api_client=api_client,
         disable_project_sync=disable_project_sync,
     )
     cluster_config = _set_anyscale_aws_node_provider(
-        cluster_config, session_name, api_client
+        cluster_config, session_name, project_id, api_client
     )
     for node_type in cluster_config["available_node_types"]:
         cluster_config["available_node_types"][node_type]["node_config"][
