@@ -211,3 +211,37 @@ def cloud_config_get(
             cloud_name=cloud_name or name, cloud_id=cloud_id,
         )
     )
+
+
+@cloud_cli.command(
+    name="secrets",
+    help="Allow clusters started in this cloud to access secrets manager.",
+    hidden=True,
+)
+@click.argument("cloud-name", required=False)
+@click.option(
+    "--name",
+    "-n",
+    help="Allow clusters started in this cloud (identified by cloud name) to access secrets manager.",
+    type=str,
+)
+@click.option(
+    "--cloud-id",
+    "--id",
+    help="Allow clusters started in this cloud (identified by cloud id) to access secrets manager.",
+    required=False,
+)
+@click.option(
+    "--yes", "-y", is_flag=True, default=False, help="Don't ask for confirmation."
+)
+def cloud_secrets(
+    cloud_name: Optional[str], name: Optional[str], cloud_id: Optional[str], yes: bool,
+) -> None:
+    if cloud_name and name and cloud_name != name:
+        raise click.ClickException(
+            "The positional argument CLOUD_NAME and the keyword argument --name "
+            "were both provided. Please only provide one of these two arguments."
+        )
+    CloudController().experimental_setup_secrets(
+        cloud_name=cloud_name or name, cloud_id=cloud_id, yes=yes
+    )
