@@ -34,6 +34,7 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 from urllib.parse import parse_qs, urlparse
 import uuid
 
+from packaging import version
 import requests
 import yaml
 
@@ -608,6 +609,52 @@ class ClientBuilder:
         self._job_config.set_metadata("job_name", job_name)
         return self
 
+    def _rewrite_runtime_env_pip_as_list(self, runtime_env: Dict[str, Any]) -> None:
+        """Parses and replaces the "pip" field of runtime_env with a List[str] if present."""
+        if "pip" in runtime_env and isinstance(runtime_env["pip"], str):
+            # We have been given a path to a requirements.txt file.
+            pip_file = Path(runtime_env["pip"])
+            if not pip_file.is_file():
+                raise ValueError(f"{pip_file} is not a valid file")
+            runtime_env["pip"] = pip_file.read_text().strip().split("\n")
+
+    def _rewrite_runtime_env_conda_as_dict(self, runtime_env: Dict[str, Any]) -> None:
+        """Parses and replaces the "conda" field of runtime_env with a Dict if present."""
+        if "conda" in runtime_env and isinstance(runtime_env["conda"], str):
+            yaml_file = Path(runtime_env["conda"])
+            if yaml_file.suffix in (".yaml", ".yml"):
+                if not yaml_file.is_file():
+                    raise ValueError(f"Can't find conda YAML file {yaml_file}.")
+                try:
+                    runtime_env["conda"] = yaml.safe_load(yaml_file.read_text())
+                except Exception as e:
+                    raise ValueError(f"Failed to read conda file {yaml_file}: {e}.")
+
+    def _pin_protobuf_in_runtime_env_if_needed(
+        self, runtime_env: Dict[str, Any]
+    ) -> None:
+        """Pins protobuf to 3.20.1 in the "pip" and "conda" field for affected Ray versions.
+
+        See https://github.com/anyscale/product/issues/12007 for details.
+        """
+        # Since Ray 1.10.0, pip installs are incremental, so the cluster's protobuf version
+        # will be inherited and there's no need to add it to the "pip" field.
+        if version.parse(self._ray.__version__) < version.parse("1.10.0"):
+            self._rewrite_runtime_env_pip_as_list(runtime_env)
+            if "pip" in runtime_env and isinstance(runtime_env["pip"], list):
+                runtime_env["pip"].append("protobuf==3.20.1")
+
+        # Fixed in Ray starting with Ray 1.13.0:
+        # https://github.com/ray-project/ray/commit/6c8eb5e2ebde8db213ffb8722a0324077188e308
+        if version.parse(self._ray.__version__) < version.parse("1.13.0"):
+            self._rewrite_runtime_env_conda_as_dict(runtime_env)
+            if "conda" in runtime_env and isinstance(runtime_env["conda"], dict):
+                if "dependencies" in runtime_env["conda"]:
+                    for dep in runtime_env["conda"]["dependencies"]:
+                        if isinstance(dep, dict) and "pip" in dep:
+                            if isinstance(dep["pip"], list):
+                                dep["pip"].append("protobuf==3.20.1")
+
     def _set_runtime_env_in_job_config(self, project_dir: Optional[str]) -> None:
         """Configures the runtime env inside self._job_config.
         project_dir is None if using the default project.
@@ -636,21 +683,10 @@ class ClientBuilder:
         # Patch for https://github.com/ray-project/ray/issues/20876
         # If local pip or conda files are specified, read them here and rewrite
         # the runtime env to prevent FileNotFoundError in the Ray Client server.
-        if "pip" in runtime_env and isinstance(runtime_env["pip"], str):
-            # We have been given a path to a requirements.txt file.
-            pip_file = Path(runtime_env["pip"])
-            if not pip_file.is_file():
-                raise ValueError(f"{pip_file} is not a valid file")
-            runtime_env["pip"] = pip_file.read_text().strip().split("\n")
-        if "conda" in runtime_env and isinstance(runtime_env["conda"], str):
-            yaml_file = Path(runtime_env["conda"])
-            if yaml_file.suffix in (".yaml", ".yml"):
-                if not yaml_file.is_file():
-                    raise ValueError(f"Can't find conda YAML file {yaml_file}.")
-                try:
-                    runtime_env["conda"] = yaml.safe_load(yaml_file.read_text())
-                except Exception as e:
-                    raise ValueError(f"Failed to read conda file {yaml_file}: {e}.")
+        self._rewrite_runtime_env_pip_as_list(runtime_env)
+        self._rewrite_runtime_env_conda_as_dict(runtime_env)
+
+        self._pin_protobuf_in_runtime_env_if_needed(runtime_env)
 
         self._job_config.set_runtime_env(runtime_env)
 
