@@ -16,9 +16,10 @@ from anyscale.aws_iam_policies import (
     AMAZON_S3_FULL_ACCESS_POLICY_ARN,
     ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN,
     ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
+    ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT,
 )
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client.models import CloudConfig, WriteCloud
+from anyscale.client.openapi_client.models import Cloud, CloudConfig, WriteCloud
 from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 from anyscale.conf import ANYSCALE_IAM_ROLE_NAME
 from anyscale.controllers.base_controller import BaseController
@@ -417,3 +418,91 @@ class CloudController(BaseController):
         )
 
         self.log.info(f"Updated default cloud to {cloud_name}")
+
+    def experimental_setup_secrets(
+        self, cloud_name: Optional[str], cloud_id: Optional[str], yes: bool = False
+    ):
+        """
+        Given a cloud name, look up its provider and give it permissions to read secrets
+        """
+        feature_flag_on = self.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
+            "wandb-integration-prototype"
+        ).result.is_on
+        if not feature_flag_on:
+            raise ClickException(
+                "Secrets can only be set up if the wandb-integration-prototype feature "
+                "flag is serving True."
+            )
+
+        cloud_id, cloud_name = get_cloud_id_and_name(
+            self.api_client, cloud_id, cloud_name
+        )
+        cloud = self.api_client.get_cloud_api_v2_clouds_cloud_id_get(cloud_id).result
+
+        self.log.info(
+            f"Setting up secrets policy for {cloud.provider} cloud {cloud.name}"
+        )
+
+        if cloud.provider == "AWS":
+            return self._experimental_grant_secrets_access_aws(cloud, yes)
+
+        if cloud.provider == "GCP":
+            raise ClickException(
+                "Cloud secrets not currently supported for GCP clouds."
+            )
+
+        raise ClickException(f"Cloud secrets not supported for {cloud_name}")
+
+    def _experimental_grant_secrets_access_aws(self, cloud: Cloud, yes: bool) -> None:
+        """Creates IAM policy for SSM readonly access and attaches it to the given role
+        Args:
+            cloud (Cloud): Cloud object which needs modification
+        """
+
+        # Ensure they are in the correct AWS account, by checking account used
+        # for Security Token Service
+        STS = "sts"
+        current_account = boto3.client(
+            STS, region_name=cloud.region
+        ).get_caller_identity()["Account"]
+        # Cloud credentials of format arn:aws:iam::{cloud_account}:role/{cloud_role}
+        # Split credentials to get cloud account.
+        cloud_account = cloud.credentials.split(":")[4]
+
+        if current_account != cloud_account:
+            raise ClickException(
+                f"The cloud you specified uses AWS account {cloud_account}, "
+                f"but you are currently logged into {current_account}."
+            )
+
+        from ray.autoscaler._private.aws.config import DEFAULT_RAY_IAM_ROLE
+
+        if yes:
+            role_name = DEFAULT_RAY_IAM_ROLE
+        else:
+            role_name = prompt(
+                "Which AWS role do you want to grant readonly SSM access to?",
+                default=DEFAULT_RAY_IAM_ROLE,
+                show_default=True,
+            )
+
+        role = _get_role(role_name, cloud.region)
+        assert (
+            role is not None
+        ), f"Failed to find IAM role {role_name} in Cloud {cloud.name}! Have you run 'cloud setup'?"
+
+        policy_name = f"anyscale-secrets-readonly-{cloud.id}"
+
+        role.Policy(name=policy_name).put(
+            PolicyDocument=json.dumps(ANYSCALE_SSM_READONLY_ACCESS_POLICY_DOCUMENT),
+        )
+        self.log.info(
+            f"Successfully added/updated inline policy {policy_name} on role {role_name}."
+        )
+        if role_name == DEFAULT_RAY_IAM_ROLE:
+            self.log.info(
+                f"Note: {role_name} is the default role used for all Anyscale clouds in "
+                f"this AWS account, so policy {policy_name} will be used by all clouds "
+                "that use this role. We are planning to create a new default role for each "
+                "Anyscale cloud in the future."
+            )
