@@ -223,7 +223,7 @@ class ClusterController(BaseController):
     ) -> None:
         if cluster_name is not None and cluster_id is not None:
             raise click.ClickException(
-                "`--name` and `--cluster-id` cannot both be specified. Please only provide one"
+                "`--name` and `--cluster-id` cannot both be specified. Please only provide one "
                 "of these two arguments."
             )
         if cluster_name is None and cluster_id is None:
@@ -467,7 +467,11 @@ class ClusterController(BaseController):
         and whether this cluster needs to be started.
         """
         cluster_list = self.anyscale_api_client.search_clusters(
-            {"project_id": project_id, "name": {"equals": cluster_name}}
+            {
+                "project_id": project_id,
+                "name": {"equals": cluster_name},
+                "archive_status": "ALL",
+            }
         ).results
 
         cluster_exists = len(cluster_list) > 0
