@@ -7,7 +7,6 @@ import time
 import traceback
 from typing import Any, cast, Dict, List, Optional, Tuple, Type, Union
 from urllib.parse import urlparse
-import uuid
 
 import click
 from pydantic import BaseModel, Field, root_validator
@@ -19,6 +18,7 @@ import yaml
 
 from anyscale.cli_logger import LogsLogger
 from anyscale.client.openapi_client import (
+    CreateCronJob,
     CreateProductionJob,
     DecoratedProductionJob,
     HaJobStates,
@@ -36,12 +36,7 @@ from anyscale.cluster_env import (
     validate_successful_build,
 )
 from anyscale.controllers.base_controller import BaseController
-from anyscale.project import (
-    find_project_root,
-    get_proj_id_from_name,
-    get_project_id,
-    ProjectDefinition,
-)
+from anyscale.project import get_proj_id_from_name, infer_project_id
 from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
 from anyscale.util import (
     extract_versions_from_image_name,
@@ -50,7 +45,7 @@ from anyscale.util import (
     poll,
     PROJECT_NAME_ENV_VAR,
 )
-from anyscale.utils.runtime_env import upload_and_rewrite_working_dir
+from anyscale.utils.runtime_env import override_runtime_env_for_local_working_dir
 
 
 log = LogsLogger()
@@ -531,12 +526,14 @@ class JobController(BaseController):
         entrypoint = entrypoint or []
         if is_anyscale_workspace() and is_entrypoint_cmd:
             entrypoint = [job_config_file, *entrypoint]
-            id = self.submit_with_entrypoint(entrypoint, name, description)
+            config = self.generate_config_from_entrypoint(entrypoint, name, description)
+            id = self.submit_from_config(config)
         elif len(entrypoint) == 0:
             # Assume that job_config_file is a file and submit it.
-            id = self.submit_from_file(
+            config = self.generate_config_from_file(
                 job_config_file, name=name, description=description
             )
+            id = self.submit_from_config(config)
         elif len(entrypoint) != 0:
             msg = (
                 "Within an Anyscale Workspace, `anyscale job submit` takes either a file, or a command. To submit a command, use `anyscale job submit -- my command`."
@@ -546,20 +543,19 @@ class JobController(BaseController):
             raise click.ClickException(msg)
         return id
 
-    def submit_with_entrypoint(
-        self, entrypoint: List[str], name: Optional[str], description: Optional[str]
-    ):
+    def generate_config_from_entrypoint(
+        self, entrypoint: List[str], name: Optional[str], description: Optional[str],
+    ) -> JobConfig:
         config_dict = {
             "entrypoint": " ".join(entrypoint),
             "name": name,
             "description": description,
         }
-        job_config = self._populate_job_config(config_dict)
-        return self.submit_from_config(job_config)
+        return self._populate_job_config(config_dict)
 
-    def submit_from_file(
+    def generate_config_from_file(
         self, job_config_file: str, name: Optional[str], description: Optional[str],
-    ) -> str:
+    ) -> JobConfig:
 
         config_dict = self._load_config_dict_from_file(job_config_file)
         job_config = self._populate_job_config(config_dict)
@@ -569,12 +565,16 @@ class JobController(BaseController):
         if description:
             job_config.description = description
 
-        return self.submit_from_config(job_config)
+        return job_config
 
     def submit_from_config(self, job_config: JobConfig):
         # If project id is not specified, try to infer it
-        project_id = self._infer_project_id(job_config)
-        self._override_runtime_env(job_config)
+        project_id = infer_project_id(
+            job_config.project_id, self.anyscale_api_client, self.log
+        )
+        job_config.runtime_env = override_runtime_env_for_local_working_dir(
+            job_config.runtime_env, self.log
+        )
 
         config_object = ProductionJobConfig(
             entrypoint=job_config.entrypoint,
@@ -592,7 +592,6 @@ class JobController(BaseController):
                 config=config_object,
             )
         ).result
-
         self.log.info(
             f"Job {job.id} has been successfully submitted. Current state of job: {job.state.current_state}."
         )
@@ -605,43 +604,65 @@ class JobController(BaseController):
         self.log.info(f'View the job in the UI at {get_endpoint(f"/jobs/{job.id}")}.')
         return job.id
 
-    def _override_runtime_env(self, job_config: JobConfig) -> JobConfig:
-        if is_anyscale_workspace():
-            import anyscale
+    def schedule(
+        self,
+        job_config_file: str,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        is_entrypoint_cmd: Optional[bool] = False,
+        entrypoint: Optional[List[str]] = None,
+        cron_expression: Optional[str] = None,
+    ) -> str:
+        entrypoint = entrypoint or []
+        if is_anyscale_workspace() and is_entrypoint_cmd:
+            entrypoint = [job_config_file, *entrypoint]
+            config = self.generate_config_from_entrypoint(entrypoint, name, description)
+            id = self.schedule_from_config(config, cron_expression=cron_expression)
+        elif len(entrypoint) == 0:
+            config = self.generate_config_from_file(
+                job_config_file, name=name, description=description
+            )
+            id = self.schedule_from_config(config, cron_expression=cron_expression)
+        elif len(entrypoint) != 0:
+            msg = (
+                "Within an Anyscale Workspace, `anyscale job schedule` takes either a file, or a command. To submit a command, use `anyscale job schedule -- my command`."
+                if is_anyscale_workspace()
+                else "`anyscale job schedule` takes one argument, a YAML file configuration. Please use `anyscale job schedule my_file`."
+            )
+            raise click.ClickException(msg)
+        return id
 
-            job_config.runtime_env = anyscale.snapshot_util.env_hook(
-                job_config.runtime_env
-            )
-            # Snapshot the working directory to EFS so the job we submit can read it from there
-            job_config.runtime_env["working_dir"] = (
-                "file://" + job_config.runtime_env["working_dir"]
-            )
-            fake_job_id = uuid.uuid4().hex
-            job_config.runtime_env = anyscale.snapshot_util.checkpoint_job(
-                fake_job_id, job_config.runtime_env
-            )
-            job_config.runtime_env["working_dir"] = (
-                "file://" + job_config.runtime_env["working_dir"]
-            )
-        elif job_config.runtime_env:
-            job_config.runtime_env = upload_and_rewrite_working_dir(
-                job_config.runtime_env, self.log
-            )
-        return job_config
+    def schedule_from_config(
+        self, job_config: JobConfig, cron_expression: Optional[str] = None
+    ):
+        # If project id is not specified, try to infer it
+        project_id = infer_project_id(
+            job_config.project_id, self.anyscale_api_client, self.log
+        )
+        job_config.runtime_env = override_runtime_env_for_local_working_dir(
+            job_config.runtime_env, self.log
+        )
 
-    def _infer_project_id(self, job_config: JobConfig) -> str:
-        project_id = job_config.project_id
-        if not project_id:
-            # Check directory of .anyscale.yaml to decide whether to use default project.
-            root_dir = find_project_root(os.getcwd())
-            if root_dir is not None:
-                project_definition = ProjectDefinition(root_dir)
-                project_id = get_project_id(project_definition.root)
-            else:
-                default_project = self.anyscale_api_client.get_default_project().result
-                project_id = default_project.id
-                self.log.info("No project specified. Continuing without a project.")
-        return cast(str, project_id)
+        config_object = ProductionJobConfig(
+            entrypoint=job_config.entrypoint,
+            runtime_env=job_config.runtime_env,
+            build_id=job_config.build_id,
+            compute_config_id=job_config.compute_config_id,
+            max_retries=job_config.max_retries,
+        )
+
+        job = self.api_client.create_or_update_job_api_v2_experimental_cron_jobs_put(
+            CreateCronJob(
+                name=job_config.name or "cli-job-{}".format(datetime.now().isoformat()),
+                description=job_config.description or "Job submitted from CLI",
+                project_id=project_id,
+                config=config_object,
+                cron_expression=cron_expression,
+            )
+        ).result
+        self.log.info(f"Scheduled Job {job.id} has been created successfully.")
+
+        return job.id
 
     def _load_config_dict_from_file(self, job_config_file: str) -> Dict[str, Any]:
         if not os.path.exists(job_config_file):
@@ -678,6 +699,7 @@ class JobController(BaseController):
         name: Optional[str],
         job_id: Optional[str],
         project_id: Optional[str],
+        include_archived: bool,
         max_items: int,
         is_service: bool = False,
     ) -> None:
@@ -742,6 +764,7 @@ class JobController(BaseController):
                 name=name,
                 creator_id=creator_id,
                 type_filter="SERVICE" if is_service else "BATCH_JOB",
+                archive_status="ALL" if include_archived else "NOT_ARCHIVED",
                 count=10,
             )
             jobs_list.extend(resp.results)
@@ -753,6 +776,7 @@ class JobController(BaseController):
                     name=name,
                     creator_id=creator_id,
                     type_filter="SERVICE" if is_service else "BATCH_JOB",
+                    archive_status="ALL" if include_archived else "NOT_ARCHIVED",
                     count=10,
                     paging_token=paging_token,
                 )
@@ -795,6 +819,25 @@ class JobController(BaseController):
         )
         print(f"{entity_type.capitalize()}:\n{table}")
 
+    def archive(
+        self, job_id: Optional[str], job_name: Optional[str], is_service: bool = False,
+    ) -> None:
+        """
+        This function will either archive jobs or services based on the value of `is_service`.
+        Both functionalities are combined in one function because the API to archive both these
+        entities is currently the same.
+        """
+        entity_type = "service" if is_service else "job"
+        job_resp: DecoratedProductionJob = self._resolve_job_object(
+            job_id, job_name, entity_type
+        )
+        self.api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post(
+            job_resp.id
+        )
+        self.log.info(
+            f"{entity_type.capitalize()} {job_resp.id} is successfully archived."
+        )
+
     def terminate(
         self, job_id: Optional[str], job_name: Optional[str], is_service: bool = False,
     ) -> None:
