@@ -11,12 +11,12 @@ from anyscale.cli_logger import BlockLogger
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.controllers.base_controller import BaseController
 from anyscale.project import (  # pylint:disable=private-import
-    _write_project_file_to_disk,
     attach_to_project_with_id,
     create_new_proj_def,
     get_proj_id_from_name,
     load_project_or_throw,
     register_or_attach_to_project,
+    write_project_file_to_disk,
 )
 from anyscale.sdk.anyscale_client import (
     PageQuery,
@@ -41,11 +41,17 @@ class ProjectController(BaseController):
         self.log = log
         self.log.open_block("Output")
 
+    def get_proj_id_from_name(
+        self, project_name: str, owner: Optional[str] = None
+    ) -> str:
+        """ Call API to get project id given a project name.  """
+        return get_proj_id_from_name(project_name, self.api_client, owner)
+
     def clone(self, project_name: str, owner: Optional[str] = None) -> None:
         project_id = get_proj_id_from_name(project_name, self.api_client, owner)
 
         os.makedirs(project_name)
-        _write_project_file_to_disk(project_id, project_name)
+        write_project_file_to_disk(project_id, project_name)
 
         self._write_sample_compute_config(
             filepath=os.path.join(project_name, COMPUTE_CONFIG_FILENAME),
