@@ -2,8 +2,6 @@ import shlex
 import subprocess
 from typing import List, Sequence
 
-from ray.autoscaler.sdk import get_docker_host_mount_location
-
 from anyscale.cli_logger import BlockLogger
 from anyscale.cluster_config import get_cluster_config
 from anyscale.controllers.base_controller import BaseController
@@ -21,7 +19,9 @@ class WorkspaceController(BaseController):
 
         self.project_definition = load_project_or_throw()
         self.project_id = self.project_definition.config["project_id"]
-        self.session = get_project_session(self.project_id, None, self.api_client)
+        self.session = get_project_session(
+            self.project_id, None, self.api_client, is_workspace=True
+        )
         # FIXME: The get_cluster_config call repeats several of the REST calls
         # of the above calls -- the CLI can be made faster if we can dedup them.
         self.cluster_config = get_cluster_config(None, self.api_client)
@@ -54,6 +54,8 @@ class WorkspaceController(BaseController):
         rsync_filters: List[str],
         rsync_excludes: List[str],
     ) -> None:
+        from ray.autoscaler.sdk import get_docker_host_mount_location
+
         ssh_user = self.cluster_config["auth"]["ssh_user"]
         key_path = self.cluster_config["auth"]["ssh_private_key"]
 
