@@ -366,3 +366,19 @@ def get_and_validate_project_id(
             )
     assert project_id  # for mypy
     return project_id
+
+
+def infer_project_id(
+    project_id: Optional[str], anyscale_api_client: DefaultApi, log: BlockLogger
+) -> str:
+    if not project_id:
+        # Check directory of .anyscale.yaml to decide whether to use default project.
+        root_dir = find_project_root(os.getcwd())
+        if root_dir is not None:
+            project_definition = ProjectDefinition(root_dir)
+            project_id = get_project_id(project_definition.root)
+        else:
+            default_project = anyscale_api_client.get_default_project().result
+            project_id = default_project.id
+            log.info("No project specified. Continuing without a project.")
+    return str(project_id)
