@@ -15,6 +15,9 @@ from anyscale.commands.cluster_compute_commands import cluster_compute_cli
 from anyscale.commands.cluster_env_commands import cluster_env_cli
 from anyscale.commands.config_commands import config_cli
 from anyscale.commands.exec_commands import anyscale_exec
+from anyscale.commands.experimental_integrations_commands import (
+    experimental_integrations_cli,
+)
 from anyscale.commands.job_commands import job_cli
 from anyscale.commands.list_commands import list_cli
 from anyscale.commands.migrate_commands import migrate_cli
@@ -118,6 +121,7 @@ cli.add_command(job_cli)
 cli.add_command(service_cli)
 cli.add_command(cluster_cli)
 cli.add_command(workspace_cli)
+cli.add_command(experimental_integrations_cli)
 cli.add_command(auth_cli)
 
 cli.add_command(anyscale_init)
