@@ -466,7 +466,20 @@ def setup_credentials():
     private_key = os.path.join(EFS_CREDS_DIR, USERNAME, "id_rsa")
     public_key = os.path.join(EFS_CREDS_DIR, USERNAME, "id_rsa.pub")
     os.path.join(EFS_CREDS_DIR, USERNAME, "env_vars.json")
-    os.makedirs("/home/ray/.ssh", exist_ok=True)
+
+    # setup ssh directory commands
+    setup_ssh_directory_cmds = [
+        "mkdir -p /home/ray/.ssh",
+        # incase the directory is already created by docker, make sure we can write to it.
+        "sudo chown ray /home/ray/.ssh",
+    ]
+
+    for cmd in setup_ssh_directory_cmds:
+        try:
+            subprocess.check_call(cmd, shell=True)  # noqa
+        except Exception:
+            logger.exception(f"Error running {cmd}")
+
     if os.path.exists(private_key):
         # Copy down from EFS.
         shutil.copy(private_key, "/home/ray/.ssh/id_rsa")
