@@ -14,10 +14,10 @@ from typing import Any, Callable, cast, Dict, Generator, Iterator, List, Optiona
 from urllib.parse import quote as quote_sanitize, urlencode, urljoin
 import webbrowser
 
+from botocore.exceptions import NoRegionError
 import click
 import requests
 from requests import Response
-from urllib3.exceptions import MaxRetryError
 import yaml
 
 from anyscale.authenticate import get_auth_api_client
@@ -212,7 +212,11 @@ def _get_user(user_name: str, region: str) -> Any:
 def get_available_regions() -> List[str]:
     import boto3
 
-    client = boto3.client("ec2")
+    try:
+        client = boto3.client("ec2")
+    except NoRegionError:
+        # If there is no region, default to `us-west-2`
+        client = boto3.client("ec2", region_name="us-west-2")
     return [region["RegionName"] for region in client.describe_regions()["Regions"]]
 
 
@@ -695,46 +699,6 @@ def canonicalize_remote_location(
     return remote_location
 
 
-def init_sentry(subcommand_group: str) -> None:
-    # Only report production and staging errors
-    if shared_anyscale_conf.ANYSCALE_ENV not in ["production", "staging"]:
-        return
-
-    try:
-        import sentry_sdk
-
-        user_info = get_user_info()
-        if user_info:
-            if user_info.email in [
-                "test@anyscale.com",
-                "ci-staging@anyscale.com",
-                "ci-production@anyscale.com",
-            ]:
-                return
-            sentry_sdk.set_user(
-                {
-                    "id": user_info.id,
-                    "email": user_info.email,
-                    "username": user_info.username,
-                }
-            )
-
-        sentry_sdk.set_tag("command", subcommand_group)
-        sentry_sdk.init(
-            "https://68d7689b55024e91bb31694539111baa@o565360.ingest.sentry.io/5706818",
-            release=get_anyscale_version(),
-            environment=shared_anyscale_conf.ANYSCALE_ENV,
-        )
-    except MaxRetryError as e:
-        log.debug(str(e))
-        log.warning(
-            "Warning: Anyscale requires a network connection to operate, are you currently "
-            "connected to the internet?"
-        )
-    except Exception as e:
-        log.warning(str(e))
-
-
 def get_user_info() -> Optional[UserInfo]:
     try:
         api_client = get_auth_api_client().api_client
@@ -789,15 +753,6 @@ def validate_non_negative_arg(ctx, param, value):
     return value
 
 
-def number_of_external_ids_in_policy(policy: Dict[str, Any]) -> int:
-    """Counts the number of External IDs in a given policy"""
-    external_ids = [
-        statement.get("Condition", {}).get("StringEquals", {}).get("sts:ExternalId", [])
-        for statement in policy.get("Statement", [])
-    ]
-    return sum(1 if isinstance(i, str) else len(i) for i in external_ids)
-
-
 def _update_external_ids_for_policy(
     original_policy: Dict[str, Any], new_external_id: str
 ):
@@ -903,3 +858,28 @@ def poll(
         sleep_till(last_poll_time + interval_secs)
         should_continue_iter = max_iter is None or count < max_iter
         should_continue_time = end_time is None or time.time() < end_time
+
+
+def is_anyscale_workspace() -> bool:
+    return "ANYSCALE_EXPERIMENTAL_WORKSPACE_ID" in os.environ
+
+
+def credentials_check_sanity(credentials_str: str) -> bool:
+    """
+    The main goal of this function is to perform a minimal sanity check
+    to make sure that the CLI token string (entered by user or read from file)
+    is not totally broken.
+    refer to https://www.notion.so/anyscale-hq/Authentication-Infrastructure
+    """
+    # Old token style
+    if credentials_str.startswith("sss_"):
+        return True
+    # Future token style
+    if credentials_str.startswith("a") and credentials_str.count("_") > 0:
+        return True
+    return False
+
+
+def get_current_cluster_id() -> Optional[str]:
+    """If we are running on an Anyscale Cluster, return the id from the environment."""
+    return os.getenv("ANYSCALE_SESSION_ID")
