@@ -25,6 +25,7 @@ import yaml
 
 from anyscale.api import configure_open_api_client_headers
 from anyscale.cli_logger import BlockLogger  # type: ignore
+from anyscale.util import is_anyscale_workspace
 import anyscale.utils.ray_conda as ray_conda
 from anyscale.utils.ray_utils import (  # type: ignore
     _dir_travel,
@@ -60,7 +61,7 @@ class ResourceType(Enum):
 
 class PackagePrefix(Enum):
     """Theses are prefix of different packages. Packages are composed by
-        base + [add] - del ==> resource_dir
+    base + [add] - del ==> resource_dir
     """
 
     # Base package is the base part for the resource
@@ -110,7 +111,9 @@ async def _get_object(  # type: ignore
     return obj["Body"]
 
 
-async def _put_object(s3, bucket: str, key: str, local_path: str,) -> None:  # type: ignore
+async def _put_object(
+    s3, bucket: str, key: str, local_path: str,
+) -> None:  # type: ignore
     await s3.put_object(Body=open(local_path, "rb"), Bucket=bucket, Key=key)
 
 
@@ -820,9 +823,9 @@ async def _handle_cache_miss(
     conda_env: Dict[str, Any],
 ) -> None:  # type: ignore
     """In case of caching miss, we'll
-        1. install from `conda_env`
-        2. use conda_pack to pack it
-        3. upload it to s3
+    1. install from `conda_env`
+    2. use conda_pack to pack it
+    3. upload it to s3
     """
     import conda_pack  # type: ignore
 
@@ -862,8 +865,8 @@ async def _handle_cache_hit(
     conda_env: Dict[str, Any],
 ) -> None:  # type: ignore
     """In case of a cache hit, we'll
-       1. download it from s3
-       2. unpack it
+    1. download it from s3
+    2. unpack it
     """
     logger.debug("Conda env has existed in s3.")
     if not resource_dir_pkg.local_path().exists():
@@ -1225,3 +1228,20 @@ def upload_and_rewrite_working_dir(
     final_runtime_env["working_dir"] = final_uploaded_filepath
 
     return final_runtime_env
+
+
+def override_runtime_env_for_local_working_dir(
+    runtime_env: Optional[Dict[str, Any]], log: BlockLogger
+) -> Optional[Dict[str, Any]]:
+    if is_anyscale_workspace():
+        import anyscale
+
+        runtime_env = anyscale.snapshot_util.env_hook(runtime_env)
+        # Snapshot the working directory to EFS so the job we submit can read it from there
+        runtime_env["working_dir"] = "file://" + runtime_env["working_dir"]
+        fake_job_id = uuid.uuid4().hex
+        runtime_env = anyscale.snapshot_util.checkpoint_job(fake_job_id, runtime_env)
+        runtime_env["working_dir"] = "file://" + runtime_env["working_dir"]
+    elif runtime_env:
+        runtime_env = upload_and_rewrite_working_dir(runtime_env, log)
+    return runtime_env
