@@ -252,9 +252,12 @@ def test_check_if_cluster_needs_start(
 ):
     mock_cluster = Mock(state=cluster_state)
     mock_cluster.name = cluster_name
-    mock_prepare_cluster_block.anyscale_api_client.search_sessions = Mock(
+    mock_prepare_cluster_block.anyscale_api_client.search_clusters = Mock(
         return_value=Mock(results=[mock_cluster] if cluster_exists else [])
     )
+    mock_prepare_cluster_block.anyscale_api_client.get_session = Mock(
+        return_value=Mock(result=mock_cluster if cluster_exists else None)
+    )
 
     if not cluster_name or cluster_state != "Running" or not cluster_exists:
         assert mock_prepare_cluster_block._check_if_cluster_needs_start(
@@ -269,8 +272,12 @@ def test_check_if_cluster_needs_start(
         )
 
     if cluster_name:
-        mock_prepare_cluster_block.anyscale_api_client.search_sessions.assert_called_once_with(
-            "test_project_id", {"name": {"equals": cluster_name}}
+        mock_prepare_cluster_block.anyscale_api_client.search_clusters.assert_called_once_with(
+            {
+                "project_id": "test_project_id",
+                "name": {"equals": cluster_name},
+                "archive_status": "ALL",
+            },
         )
 
 
