@@ -117,16 +117,16 @@ def test_submit_job(
     job_controller = JobController()
     mock_project_definition = Mock()
     mock_project_definition.root = "/some/directory"
-    if use_default_project:
-        mock_find_project_root = Mock(return_value=None)
-        job_controller.anyscale_api_client.get_default_project = Mock(
-            return_value=Mock(result=Mock(id="mock_default_project_id"))
-        )
-    else:
-        mock_find_project_root = Mock(return_value="root_path")
 
-    mock_get_project_id = Mock(return_value="mock_project_id")
+    def infer_project_id_mock(project_id: str, *args: Any):
+        if project_id:
+            return project_id
+        elif use_default_project:
+            return "mock_default_project_id"
+        else:
+            return "mock_project_id"
 
+    mock_infer_project_id = Mock(side_effect=infer_project_id_mock)
     mock_get_build_from_cluster_env_identifier = Mock(
         return_value=Mock(id="mock_build_id")
     )
@@ -146,8 +146,7 @@ def test_submit_job(
         "builtins.open", mock_open(read_data=json.dumps(config_dict))
     ), patch.multiple(
         "anyscale.controllers.job_controller",
-        find_project_root=mock_find_project_root,
-        get_project_id=mock_get_project_id,
+        infer_project_id=mock_infer_project_id,
         get_build_from_cluster_env_identifier=mock_get_build_from_cluster_env_identifier,
         get_cluster_compute_from_name=mock_get_cluster_compute_from_name,
         get_default_cluster_compute=mock_get_default_cluster_compute,
@@ -161,8 +160,6 @@ def test_submit_job(
             "mock_config_file", name="mock_name", description="mock_description"
         )
     mock_validate_successful_build.assert_called_once_with("mock_build_id")
-    if use_default_project and not config_project_id:
-        job_controller.anyscale_api_client.get_default_project.assert_called_once_with()
 
     if config_project_id:
         final_project_id = config_project_id
@@ -210,6 +207,7 @@ def test_submit_job(
 @pytest.mark.parametrize(
     "passed_service_id", [False, True]
 )  # Whether `job_id` is id of job or service
+@pytest.mark.parametrize("include_archived", [False, True])
 def test_list_jobs(
     mock_auth_api_client,
     include_all_users: bool,
@@ -218,6 +216,7 @@ def test_list_jobs(
     project_id: Optional[str],
     is_service: bool,
     passed_service_id: bool,
+    include_archived: bool,
 ) -> None:
     job_controller = JobController()
     job_controller.api_client.get_user_info_api_v2_userinfo_get = Mock(
@@ -248,6 +247,7 @@ def test_list_jobs(
                 job_id=job_id,
                 project_id=project_id,
                 is_service=is_service,
+                include_archived=include_archived,
                 max_items=20,
             )
         return
@@ -258,6 +258,7 @@ def test_list_jobs(
             job_id=job_id,
             project_id=project_id,
             is_service=is_service,
+            include_archived=include_archived,
             max_items=20,
         )
 
@@ -280,6 +281,7 @@ def test_list_jobs(
             name=name,
             project_id=project_id,
             type_filter="SERVICE" if is_service else "BATCH_JOB",
+            archive_status="ALL" if include_archived else "NOT_ARCHIVED",
             count=10,
         )
         job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_any_call(
@@ -287,6 +289,7 @@ def test_list_jobs(
             name=name,
             project_id=project_id,
             type_filter="SERVICE" if is_service else "BATCH_JOB",
+            archive_status="ALL" if include_archived else "NOT_ARCHIVED",
             count=10,
             paging_token="paging_token",
         )
@@ -327,6 +330,35 @@ def test_terminate_job(
         )
 
 
+@pytest.mark.parametrize("is_service", [False, True])
+@pytest.mark.parametrize("name", ["mock_job_name", None])
+@pytest.mark.parametrize("id", ["mock_job_id", None])
+def test_archive_job(
+    mock_auth_api_client, name: Optional[str], id: Optional[str], is_service: bool,
+) -> None:
+    job_controller = JobController()
+    job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get = Mock(
+        return_value=Mock(results=[Mock(id="mock_job_id")])
+    )
+    job_controller.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get = Mock(
+        return_value=Mock(result=Mock(id="mock_job_id"))
+    )
+    if not name and not id:
+        with pytest.raises(click.ClickException):
+            job_controller.archive(id, name, is_service)
+        return
+    else:
+        job_controller.archive(id, name, is_service)
+
+    job_controller.api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post.assert_called_once_with(
+        "mock_job_id"
+    )
+    if name is not None and id is None:
+        job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_called_once_with(
+            name=name, type_filter="SERVICE" if is_service else "BATCH_JOB",
+        )
+
+
 class TestValidateConda:
     def test_validate_conda_str(self, test_directory, patch_jobs_anyscale_api_client):
         """Tests the conda field is allowed to be a str. It represents an existing env name."""
@@ -817,8 +849,9 @@ def test_wait_for_job_running(mock_auth_api_client) -> None:
 
 def test_job_submit_parse_logic(mock_auth_api_client) -> None:
     job_controller = JobController()
-    job_controller.submit_with_entrypoint = Mock()  # type: ignore
-    job_controller.submit_from_file = Mock()  # type: ignore
+    job_controller.generate_config_from_entrypoint = Mock()  # type: ignore
+    job_controller.generate_config_from_file = Mock()  # type: ignore
+    job_controller.submit_from_config = Mock()  # type: ignore
 
     # We are not in a workspace, so entrypoint should not be allowed
     with pytest.raises(click.ClickException):
@@ -835,21 +868,103 @@ def test_job_submit_parse_logic(mock_auth_api_client) -> None:
         )
 
     # Simulate a workspace
-    os.environ["ANYSCALE_EXPERIMENTAL_WORKSPACE_ID"] = "fake_workspace_id"
+    with patch.dict(
+        os.environ, {"ANYSCALE_EXPERIMENTAL_WORKSPACE_ID": "fake_workspace_id"}
+    ):
+        # Fails due to is_entrypoint_cmd being False
+        with pytest.raises(click.ClickException):
+            job_controller.submit(
+                "file", entrypoint=["entrypoint"], is_entrypoint_cmd=False
+            )
 
-    # Fails due to is_entrypoint_cmd being False
+        mock_config = Mock()
+        job_controller.generate_config_from_file.return_value = mock_config
+        job_controller.submit("file", entrypoint=[], is_entrypoint_cmd=False)
+        job_controller.generate_config_from_file.assert_called_once_with(
+            "file", name=None, description=None
+        )
+        job_controller.submit_from_config.assert_called_once_with(mock_config)
+        job_controller.generate_config_from_file.reset_mock()
+        job_controller.submit_from_config.reset_mock()
+
+        mock_config = Mock()
+        job_controller.generate_config_from_entrypoint.return_value = mock_config
+        job_controller.submit("file", entrypoint=["entrypoint"], is_entrypoint_cmd=True)
+        job_controller.generate_config_from_entrypoint.assert_called_once_with(
+            ["file", "entrypoint"], None, None
+        )
+        job_controller.submit_from_config.assert_called_once_with(mock_config)
+
+
+def test_job_schedule_parse_logic(mock_auth_api_client) -> None:
+    job_controller = JobController()
+    job_controller.generate_config_from_entrypoint = Mock()  # type: ignore
+    job_controller.generate_config_from_file = Mock()  # type: ignore
+    job_controller.schedule_from_config = Mock()  # type: ignore
+
+    # We are not in a workspace, so entrypoint should not be allowed
     with pytest.raises(click.ClickException):
-        job_controller.submit(
-            "file", entrypoint=["entrypoint"], is_entrypoint_cmd=False
+        job_controller.schedule(
+            "file",
+            entrypoint=["entrypoint"],
+            is_entrypoint_cmd=False,
+            cron_expression="0 0 1 * *",
         )
 
-    job_controller.submit("file", entrypoint=[], is_entrypoint_cmd=False)
-    job_controller.submit_from_file.assert_called_once_with(
-        "file", name=None, description=None
-    )
-    job_controller.submit_from_file.reset_mock()
+    with pytest.raises(click.ClickException):
+        job_controller.schedule(
+            "file",
+            entrypoint=["entrypoint"],
+            is_entrypoint_cmd=True,
+            cron_expression="0 0 1 * *",
+        )
 
-    job_controller.submit("file", entrypoint=["entrypoint"], is_entrypoint_cmd=True)
-    job_controller.submit_with_entrypoint.assert_called_once_with(
-        ["file", "entrypoint"], None, None
-    )
+    with pytest.raises(click.ClickException):
+        job_controller.schedule(
+            "file",
+            entrypoint=["entrypoint", "commands"],
+            is_entrypoint_cmd=True,
+            cron_expression="0 0 1 * *",
+        )
+
+    # Simulate a workspace
+    with patch.dict(
+        os.environ, {"ANYSCALE_EXPERIMENTAL_WORKSPACE_ID": "fake_workspace_id"}
+    ):
+        # Fails due to is_entrypoint_cmd being False
+        with pytest.raises(click.ClickException):
+            job_controller.schedule(
+                "file",
+                entrypoint=["entrypoint"],
+                is_entrypoint_cmd=False,
+                cron_expression="0 0 1 * *",
+            )
+
+        mock_config = Mock()
+        job_controller.generate_config_from_file.return_value = mock_config
+        job_controller.schedule(
+            "file", entrypoint=[], is_entrypoint_cmd=False, cron_expression="0 0 1 * *"
+        )
+        job_controller.generate_config_from_file.assert_called_once_with(
+            "file", name=None, description=None
+        )
+        job_controller.schedule_from_config.assert_called_once_with(
+            mock_config, cron_expression="0 0 1 * *"
+        )
+        job_controller.generate_config_from_file.reset_mock()
+        job_controller.schedule_from_config.reset_mock()
+
+        mock_config = Mock()
+        job_controller.generate_config_from_entrypoint.return_value = mock_config
+        job_controller.schedule(
+            "file",
+            entrypoint=["entrypoint"],
+            is_entrypoint_cmd=True,
+            cron_expression="0 0 1 * *",
+        )
+        job_controller.generate_config_from_entrypoint.assert_called_once_with(
+            ["file", "entrypoint"], None, None
+        )
+        job_controller.schedule_from_config.assert_called_once_with(
+            mock_config, cron_expression="0 0 1 * *"
+        )
