@@ -9,6 +9,7 @@ from anyscale.client.openapi_client import Session, SessionListResponse
 from anyscale.client.openapi_client.models.project import Project
 from anyscale.util import (
     canonicalize_remote_location,
+    credentials_check_sanity,
     deserialize_datetime,
     get_project_directory_name,
     get_working_dir,
@@ -177,3 +178,16 @@ def test_validate_cluster_configuration(project_test_data: Project) -> None:
     mock_api_client.validate_cluster_api_v2_sessions_validate_cluster_post.assert_called_once_with(
         body={"config": json.dumps(cluster_config)}
     )
+
+
+def test_credentials_check_sanity():
+    # valid credentials
+    assert credentials_check_sanity("sss_abcdefg1234567")
+    assert credentials_check_sanity("aph0_abcdefg1234567")
+    assert credentials_check_sanity("ash0_abcdefg1234567")
+    assert credentials_check_sanity("sss_this-=!./#should_3$be_a_valid_ToKEn.%")
+    assert credentials_check_sanity("aph0_052943312512")
+
+    # wrong or no prefix
+    assert not credentials_check_sanity("wrong_abcdefg1234567")
+    assert not credentials_check_sanity("withoutanyprefixes")
