@@ -11,6 +11,7 @@ from packaging import version
 import pytest
 import ray
 import requests
+import yaml
 
 import anyscale
 from anyscale.client.openapi_client import SessionListResponse
@@ -226,7 +227,10 @@ def _make_test_builder(
     ]
     sess_resp.metadata.next_paging_token = None
     sdk.list_sessions.return_value = sess_resp
-    sdk.search_sessions.return_value = sess_resp
+    sdk.search_clusters.return_value = sess_resp
+    sdk.get_session.return_value = (
+        Mock(result=sess_resp.results[0]) if sess_resp.results else None
+    )
     proj_resp = Mock()
     proj_resp.result.name = "scratch"
     sdk.get_project.return_value = proj_resp
@@ -598,7 +602,7 @@ def test_new_proj_connect_params(
 ) -> None:
     project_dir = (tmp_path / "my_proj").absolute().as_posix()
     builder, _, _, _ = _make_test_builder(tmp_path)
-    mock_cluster = builder._anyscale_sdk.search_sessions.return_value.results[0]
+    mock_cluster = builder._anyscale_sdk.get_session.return_value.result
 
     mock_project_block = mock_get_project_block.return_value
     mock_project_block.project_dir = project_dir
@@ -655,7 +659,7 @@ def test_local_docker_run_mode(
     # Making scratch dir because get_project_block is mocked out
     os.mkdir(scratch_dir)
     builder, _, subprocess, _ = _make_test_builder(tmp_path)
-    mock_cluster = builder._anyscale_sdk.search_sessions.return_value.results[0]
+    mock_cluster = builder._anyscale_sdk.search_clusters.return_value.results[0]
     mock_get_prepare_cluster_block.return_value.cluster_name = mock_cluster.name
     mock_get_project_block.return_value.project_dir = scratch_dir
 
@@ -689,7 +693,7 @@ def test_connect_with_cloud(
 ) -> None:
     scratch_dir = (tmp_path / "scratch").absolute().as_posix()
     builder, _, _, _ = _make_test_builder(tmp_path)
-    mock_cluster = builder._anyscale_sdk.search_sessions.return_value.results[0]
+    mock_cluster = builder._anyscale_sdk.search_clusters.return_value.results[0]
     mock_get_prepare_cluster_block.return_value.cluster_name = mock_cluster.name
     mock_get_project_block.return_value.project_dir = scratch_dir
 
@@ -726,7 +730,7 @@ def test_connect_with_cluster_env_dict(
 ) -> None:
     scratch_dir = (tmp_path / "scratch").absolute().as_posix()
     builder, _, _, _ = _make_test_builder(tmp_path)
-    mock_cluster = builder._anyscale_sdk.search_sessions.return_value.results[0]
+    mock_cluster = builder._anyscale_sdk.search_clusters.return_value.results[0]
     mock_get_prepare_cluster_block.return_value.cluster_name = mock_cluster.name
     mock_get_project_block.return_value.project_dir = scratch_dir
 
@@ -803,7 +807,7 @@ def test_multiple_clients(
         )
         builder, _, _, _ = _make_test_builder(tmp_path)
         scratch_dir = (tmp_path / "scratch").absolute().as_posix()
-        mock_cluster = builder._anyscale_sdk.search_sessions.return_value.results[0]
+        mock_cluster = builder._anyscale_sdk.search_clusters.return_value.results[0]
         mock_get_prepare_cluster_block.return_value.cluster_name = mock_cluster.name
         mock_get_project_block.return_value.project_dir = scratch_dir
 
@@ -953,6 +957,62 @@ def test_namespace(mock_auth_api_client) -> None:
     assert connect_instance._job_config.ray_namespace == "mock_namespace"
 
 
+@pytest.mark.parametrize("field", ["pip", "conda"])
+@pytest.mark.parametrize("type", ["python_object", "file"])
+@pytest.mark.parametrize("ray_version", ["1.9.2", "1.10.0", "1.13.0"])
+def test_pin_protobuf_in_runtime_env_if_needed(
+    type, field, ray_version, monkeypatch, tmp_path, mock_auth_api_client
+):
+    """Test that protobuf is correctly pinned for old Ray versions.
+
+    Also tests that pip/conda spec files are correctly read into Python
+    and set in the job config on the local machine before connecting.
+    """
+    if type == "file":
+        if field == "pip":
+            file = tmp_path / "requirements.txt"
+            file.write_text("requests" + "\n")
+            runtime_env = {"pip": str(file)}
+        elif field == "conda":
+            file = tmp_path / "environment.yaml"
+            conda_dict = {"dependencies": ["pip", {"pip": ["requests"]}]}
+            with file.open("w") as f:
+                yaml.dump(conda_dict, f)
+            runtime_env = {"conda": str(file)}
+    else:
+        if field == "pip":
+            runtime_env = {"pip": ["requests"]}
+        elif field == "conda":
+            runtime_env = {"conda": {"dependencies": ["pip", {"pip": ["requests"]}]}}
+
+    sdk = Mock()
+    _api_client = Mock()
+    connect_instance = ClientBuilder(
+        anyscale_sdk=sdk,
+        auth_api_client=Mock(api_client=_api_client, anyscale_api_client=Mock()),
+    )
+    monkeypatch.setattr(ray, "__version__", ray_version)
+
+    connect_instance.env(runtime_env)._set_runtime_env_in_job_config(project_dir=None)
+
+    if ray_version in ["1.10.0", "1.13.0"]:
+        desired_pip = ["requests"]
+    elif ray_version == "1.9.2":
+        desired_pip = ["requests", "protobuf==3.20.1"]
+
+    if ray_version in ["1.9.2", "1.10.0"]:
+        desired_conda = {
+            "dependencies": ["pip", {"pip": ["requests", "protobuf==3.20.1"]}]
+        }
+    elif ray_version == "1.13.0":
+        desired_conda = {"dependencies": ["pip", {"pip": ["requests"]}]}
+
+    if field == "pip":
+        assert connect_instance._job_config.runtime_env["pip"] == desired_pip
+    elif field == "conda":
+        assert connect_instance._job_config.runtime_env["conda"] == desired_conda
+
+
 def test_set_runtime_env_in_job_config(
     tmp_path: Path,
     mock_auth_api_client,
@@ -1007,11 +1067,17 @@ def test_set_runtime_env_in_job_config(
         "/.anyscale.yaml",
         "/session-default.yaml",
     ]
-    assert connect_instance._job_config.runtime_env["pip"] == ["numpy"]
+    if version.parse(ray.__version__) < version.parse("1.10.0"):
+        assert connect_instance._job_config.runtime_env["pip"] == [
+            "numpy",
+            "protobuf==3.20.1",
+        ]
+    else:
+        assert connect_instance._job_config.runtime_env["pip"] == ["numpy"]
 
     proj_dir = "/tmp"
     connect_instance, _, _, _ = _make_test_builder(tmp_path)
-    mock_cluster = connect_instance._anyscale_sdk.search_sessions.return_value.results[
+    mock_cluster = connect_instance._anyscale_sdk.search_clusters.return_value.results[
         0
     ]
     mock_cluster.user_service_url = "mock_user_service_url"
